@@ -69,7 +69,7 @@ class ControllerNode(object):
                 self.handle_peer(addr, msg_factory(msg_buf))
                 return
             if is_rpc:
-                tmp = [addr, '', msg_buf]
+                tmp = [addr, b'', msg_buf]
             else:
                 tmp = [addr, msg_buf]
             self.socket.send_multipart(tmp)
@@ -258,7 +258,7 @@ class ControllerNode(object):
         data = self.socket.recv_multipart()
         binary, sender = None, None  # initialise outside for edge cases
         if len(data) == 3:
-            if data[1] == '':  # This is a RPC call from a zmq.REQ socket
+            if data[1] == b'':  # This is a RPC call from a zmq.REQ socket
                 sender, _blank, msg_buf = data
                 self.handle_rpc(sender, msg_factory(msg_buf))
                 return
@@ -286,8 +286,8 @@ class ControllerNode(object):
             node = data.get('node')
             uptime = data.get('uptime')
             if addr and node:
-                self.others[addr]['node'] = node
-                self.others[addr]['uptime'] = uptime
+                self.others[ens_bytes(addr)]['node'] = node
+                self.others[ens_bytes(addr)]['uptime'] = uptime
             else:
                 self.logger.critical("bogus Info message received from %s %s", sender, msg)
         else:
